@@ -2,6 +2,7 @@
 
 use blez::{Adapter, AdapterEvent, Address, DeviceEvent};
 use futures::{pin_mut, stream::SelectAll, StreamExt};
+use std::env;
 
 async fn query_device(adapter: &Adapter, addr: Address) -> blez::Result<()> {
     let device = adapter.device(addr)?;
@@ -23,12 +24,15 @@ async fn query_device(adapter: &Adapter, addr: Address) -> blez::Result<()> {
 
 #[tokio::main(flavor = "current_thread")]
 async fn main() -> blez::Result<()> {
+    let with_changes = env::args().any(|arg| arg == "--changes");
+
     env_logger::init();
     let session = blez::Session::new().await?;
     let adapter_names = session.adapter_names().await?;
     let adapter_name = adapter_names.first().expect("No Bluetooth adapter present");
     println!("Discovering devices using Bluetooth adapater {}\n", &adapter_name);
     let adapter = session.adapter(&adapter_name)?;
+    adapter.set_powered(true).await?;
 
     let device_events = adapter.discover_devices().await?;
     pin_mut!(device_events);
@@ -45,9 +49,11 @@ async fn main() -> blez::Result<()> {
                             println!("    Error: {}", &err);
                         }
 
-                        let device = adapter.device(addr)?;
-                        let change_events = device.events().await?.map(move |evt| (addr, evt));
-                        all_change_events.push(change_events);
+                        if with_changes {
+                            let device = adapter.device(addr)?;
+                            let change_events = device.events().await?.map(move |evt| (addr, evt));
+                            all_change_events.push(change_events);
+                        }
                     }
                     AdapterEvent::DeviceRemoved(addr) => {
                         println!("Device removed: {}", addr);
