@@ -1,11 +1,11 @@
 //! Serves a Bluetooth GATT application using the callback programming model.
 
 use blez::{
+    adv::Advertisement,
     gatt::local::{
         Application, Characteristic, CharacteristicNotify, CharacteristicNotifyMethod, CharacteristicRead,
         CharacteristicWrite, CharacteristicWriteMethod, Service,
     },
-    Advertisement,
 };
 use futures::FutureExt;
 use std::{collections::BTreeMap, sync::Arc, time::Duration};
@@ -24,6 +24,7 @@ async fn main() -> blez::Result<()> {
     let adapter_names = session.adapter_names().await?;
     let adapter_name = adapter_names.first().expect("No Bluetooth adapter present");
     let adapter = session.adapter(&adapter_name)?;
+    adapter.set_powered(true).await?;
 
     println!("Advertising on Bluetooth adapter {} with address {}", &adapter_name, adapter.address().await?);
     let mut manufacturer_data = BTreeMap::new();
