@@ -1,6 +1,6 @@
 //! Perform a Bluetooth LE advertisement.
 
-use blez::Advertisement;
+use blez::adv::Advertisement;
 use std::time::Duration;
 use tokio::{
     io::{AsyncBufReadExt, BufReader},
@@ -14,10 +14,11 @@ async fn main() -> blez::Result<()> {
     let adapter_names = session.adapter_names().await?;
     let adapter_name = adapter_names.first().expect("No Bluetooth adapter present");
     let adapter = session.adapter(&adapter_name)?;
+    adapter.set_powered(true).await?;
 
     println!("Advertising on Bluetooth adapter {} with address {}", &adapter_name, adapter.address().await?);
     let le_advertisement = Advertisement {
-        advertisement_type: blez::AdvertisementType::Peripheral,
+        advertisement_type: blez::adv::Type::Peripheral,
         service_uuids: vec!["123e4567-e89b-12d3-a456-426614174000".parse().unwrap()].into_iter().collect(),
         discoverable: Some(true),
         local_name: Some("le_advertise".to_string()),
