@@ -38,8 +38,9 @@ impl Default for Type {
     }
 }
 
-/// Secondary channel to be used.
+/// Secondary channel for advertisement.
 #[derive(Clone, Copy, Debug, Eq, PartialEq, PartialOrd, Ord, Hash, Display, EnumString)]
+#[non_exhaustive]
 pub enum SecondaryChannel {
     /// 1M
     #[strum(serialize = "1M")]
@@ -60,6 +61,7 @@ impl Default for SecondaryChannel {
 
 /// Advertisement feature.
 #[derive(Clone, Copy, Debug, Eq, PartialEq, PartialOrd, Ord, Hash, Display, EnumString)]
+#[non_exhaustive]
 pub enum Feature {
     /// TX power.
     #[strum(serialize = "tx-power")]
@@ -74,6 +76,7 @@ pub enum Feature {
 
 /// LE advertising platform feature.
 #[derive(Clone, Copy, Debug, Eq, PartialEq, PartialOrd, Ord, Hash, Display, EnumString)]
+#[non_exhaustive]
 pub enum PlatformFeature {
     /// Indicates whether platform can
     /// specify TX power on each
@@ -89,6 +92,7 @@ pub enum PlatformFeature {
 
 /// Advertising-related controller capabilities.
 #[derive(Clone, Debug, Default, Eq, PartialEq, PartialOrd, Ord, Hash)]
+#[non_exhaustive]
 pub struct Capabilities {
     /// Maximum advertising data length.
     pub max_advertisement_length: u8,
@@ -125,7 +129,7 @@ pub struct Advertisement {
     /// List of UUIDs to include in the "Service UUID" field of
     /// the Advertising Data.
     pub service_uuids: BTreeSet<Uuid>,
-    /// Manufactuer Data fields to include in
+    /// Manufacturer Data fields to include in
     ///	the Advertising Data.
     ///
     /// Keys are the Manufacturer ID
